pub struct Aeko721Collection {
pub authority: PubkeyString,
pub name: String,
pub symbol: String,
pub base_uri: Option<String>,
pub total_minted: u64,
pub is_initialized: bool,
}Fields
name: Stringsymbol: Stringbase_uri: Option<String>total_minted: u64is_initialized: boolTrait Implementations
Sourceimpl BorshDeserialize for Aeko721Collection
impl BorshDeserialize for Aeko721Collection
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Aeko721Collection
impl BorshSerialize for Aeko721Collection
Sourceimpl Clone for Aeko721Collection
impl Clone for Aeko721Collection
Sourcefn clone(&self) -> Aeko721Collection
fn clone(&self) -> Aeko721Collection
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Aeko721Collection
impl Debug for Aeko721Collection
Sourceimpl PartialEq for Aeko721Collection
impl PartialEq for Aeko721Collection
impl Eq for Aeko721Collection
impl StructuralPartialEq for Aeko721Collection