pub struct Aeko721Token {
pub collection: PubkeyString,
pub token_id: u64,
pub owner: PubkeyString,
pub creator: PubkeyString,
pub royalty_bps: u16,
pub metadata: NftMetadata,
pub frozen: bool,
pub is_initialized: bool,
}Fields
collection: PubkeyStringtoken_id: u64owner: PubkeyStringcreator: PubkeyStringroyalty_bps: u16metadata: NftMetadatafrozen: boolis_initialized: boolTrait Implementations
Sourceimpl BorshDeserialize for Aeko721Token
impl BorshDeserialize for Aeko721Token
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Aeko721Token
impl BorshSerialize for Aeko721Token
Sourceimpl Clone for Aeko721Token
impl Clone for Aeko721Token
Sourcefn clone(&self) -> Aeko721Token
fn clone(&self) -> Aeko721Token
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Aeko721Token
impl Debug for Aeko721Token
Sourceimpl PartialEq for Aeko721Token
impl PartialEq for Aeko721Token
impl Eq for Aeko721Token
impl StructuralPartialEq for Aeko721Token