pub struct MetadataAttribute {
pub trait_type: String,
pub value: String,
}Fields
trait_type: Stringvalue: StringTrait Implementations
Sourceimpl BorshDeserialize for MetadataAttribute
impl BorshDeserialize for MetadataAttribute
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for MetadataAttribute
impl BorshSerialize for MetadataAttribute
Sourceimpl Clone for MetadataAttribute
impl Clone for MetadataAttribute
Sourcefn clone(&self) -> MetadataAttribute
fn clone(&self) -> MetadataAttribute
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MetadataAttribute
impl Debug for MetadataAttribute
Sourceimpl PartialEq for MetadataAttribute
impl PartialEq for MetadataAttribute
impl Eq for MetadataAttribute
impl StructuralPartialEq for MetadataAttribute