pub struct NftMetadata {
pub name: String,
pub description: Option<String>,
pub uri: String,
pub image_uri: Option<String>,
pub attributes: Vec<MetadataAttribute>,
}Fields
name: Stringdescription: Option<String>uri: Stringimage_uri: Option<String>attributes: Vec<MetadataAttribute>Trait Implementations
Sourceimpl BorshDeserialize for NftMetadata
impl BorshDeserialize for NftMetadata
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for NftMetadata
impl BorshSerialize for NftMetadata
Sourceimpl Clone for NftMetadata
impl Clone for NftMetadata
Sourcefn clone(&self) -> NftMetadata
fn clone(&self) -> NftMetadata
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NftMetadata
impl Debug for NftMetadata
Sourceimpl PartialEq for NftMetadata
impl PartialEq for NftMetadata
impl Eq for NftMetadata
impl StructuralPartialEq for NftMetadata